@@ -1,15 +1,9 @@
 import sqlalchemy as sa
 from .versioned import Versioned
-from .listener import (
-    configure_versioned_classes,
-    instrument_versioned_classes,
-    make_versioned
-)
+from .listener import make_versioned
 
 __all__ = (
     Versioned,
-    configure_versioned_classes,
-    instrument_versioned_classes,
     make_versioned
 )
 
