@@ -1,11 +1,9 @@
 from copy import copy
-from inflection import pluralize, underscore
 import sqlalchemy as sa
 from sqlalchemy_utils.functions import primary_keys
 from .builder import VersionedBuilder
 from .expression_reflector import ClassExpressionReflector
 from .version import VersionClassBase
-from .versioned import Versioned
 
 
 class VersionedModelBuilder(VersionedBuilder):
@@ -37,6 +35,7 @@ class VersionedModelBuilder(VersionedBuilder):
     def build_transaction_relationship(self, transaction_log_class):
         # Only define transaction relation if it doesn't already exist in
         # parent class.
+        naming_func = self.manager.DEFAULT_OPTIONS['relation_naming_function']
         if not hasattr(self.extension_class, 'transaction'):
             self.extension_class.transaction = sa.orm.relationship(
                 transaction_log_class,
@@ -45,13 +44,13 @@ class VersionedModelBuilder(VersionedBuilder):
                     self.extension_class.transaction_id
                 ),
                 foreign_keys=[self.extension_class.transaction_id],
-                backref=pluralize(underscore(self.model.__name__))
+                backref=naming_func(self.model.__name__)
             )
 
     def find_closest_versioned_parent(self):
         for class_ in self.model.__bases__:
-            if class_ in Versioned.HISTORY_CLASS_MAP:
-                return (Versioned.HISTORY_CLASS_MAP[class_], )
+            if class_ in self.manager.history_class_map:
+                return (self.manager.history_class_map[class_], )
 
     def base_classes(self):
         parents = (
@@ -60,6 +59,17 @@ class VersionedModelBuilder(VersionedBuilder):
         )
         return parents + (VersionClassBase, )
 
+    def inheritance_args(self):
+        if self.find_closest_versioned_parent():
+            reflector = ClassExpressionReflector(self.model)
+            inherit_condition = reflector(
+                self.model.__mapper__.inherit_condition
+            )
+            return {
+                'inherit_condition': inherit_condition
+            }
+        return {}
+
     def build_model(self, table):
         if not self.option('base_classes'):
             raise Exception(
@@ -67,14 +77,8 @@ class VersionedModelBuilder(VersionedBuilder):
                 % self.model.__name__
             )
         mapper_args = {}
-        if self.find_closest_versioned_parent():
-            reflector = ClassExpressionReflector(self.model)
-            inherit_condition = reflector(
-                self.model.__mapper__.inherit_condition
-            )
-            mapper_args = {
-                'inherit_condition': inherit_condition
-            }
+        mapper_args.update(self.inheritance_args())
+
         return type(
             '%sHistory' % self.model.__name__,
             self.base_classes(),
@@ -95,4 +99,4 @@ class VersionedModelBuilder(VersionedBuilder):
         self.build_transaction_relationship(transaction_log_class)
         self.model.__versioned__['class'] = self.extension_class
         self.extension_class.__parent_class__ = self.model
-        Versioned.HISTORY_CLASS_MAP[self.model] = self.extension_class
+        self.manager.history_class_map[self.model] = self.extension_class
